<?php
/**
 * Writes the given text with a border into the image using TrueType fonts.
 * @author John Ciacia < John@extreme-hq.com >
 * @param image An image resource.
 * @param size The font size.
 * @param angle The angle in degrees to rotate the text.
 * @param x Upper left corner of the text.
 * @param y Lower left corner of the text.
 * @param textcolor This is the color of the main text.
 * @param strokecolor This is the color of the text border.
 * @param fontfile The path to the TrueType font you wish to use.
 * @param text The text string in UTF-8 encoding.
 * @param px Number of pixels the text border will be.
 * @return Returns an array with 8 elements representing four points making the bounding 
 *         box of the text. The order of the points is lower left, lower right, upper right, 
 *         upper left. The points are relative to the text regardless of the angle, so 
 *         "upper left" means in the top left-hand corner when you see the text horizontally.
 * @see http://us.php.net/manual/en/function.imagettftext.php
 * @see http://forum.codecall.net
 * @see http://www.extreme-hq.com
 */
function imagettfstroketext(&$image, $size, $angle, $x, $y, &$textcolor, &$strokecolor, $fontfile, $text, $px) {

    for($c1 = ($x-abs($px)); $c1 <= ($x+abs($px)); $c1++)
        for($c2 = ($y-abs($px)); $c2 <= ($y+abs($px)); $c2++)
            $bg = imagettftext($image, $size, $angle, $c1, $c2, $strokecolor, $fontfile, $text);

   return imagettftext($image, $size, $angle, $x, $y, $textcolor, $fontfile, $text);
}  

?>